aboutsummaryrefslogtreecommitdiffstats
path: root/button.lua
diff options
context:
space:
mode:
Diffstat (limited to 'button.lua')
-rw-r--r--button.lua7
1 files changed, 4 insertions, 3 deletions
diff --git a/button.lua b/button.lua
index 94ff634..b601458 100644
--- a/button.lua
+++ b/button.lua
@@ -13,9 +13,10 @@ return function(title, x,y, w,h, draw)
-- core.mouse.updateState(id, x,y,w,h) updates the state for this widget.
core.mouse.updateState(id, x,y,w,h)
- -- core.makeTabable makes the item focus on tab. Tab order is determied
- -- by the order you call the widget functions.
- core.makeTabable(id)
+ -- core.makeCyclable makes the item focus on tab or whatever binding is
+ -- in place (see core.keyboard.cycle). Cycle order is determied by the
+ -- order you call the widget functions.
+ core.makeCyclable(id)
-- core.registerDraw(id, drawfunction, drawfunction-arguments...)
-- shows widget when core.draw() is called.